import sys
import boto3, botocore
sys.path.append( '../')
from common.args import *

def list_bucket_objects(args):
    """
    Returns the provided bucket's objects.\n
    See more about this operation at:\n
    https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/s3/client/list_objects_v2.html

    Example
    -----------
    list_bucket_objects(bucket_args())

    Parameters
    ------------
        args: argparse.Namespace\n
        The argparse generated by the ../common/args.py script

    Return
    -----------
        bucket_key : list of strings
            A list of strings containing the bucket's key names
    """
    object_keys = []
    try:
        s3 = boto3.client('s3', region_name=args.aws_region)
        response = s3.list_objects_v2(
                        Bucket=args.bucket,
                        Prefix="" if not args.prefix else args.prefix
                    )
        # print(response) # get the full response
        if 'Contents' not in response:
            return []
        for entry in response['Contents']:
            object_keys.append(entry["Key"])
        return object_keys

    except botocore.exceptions.ClientError as err:
        if err.response['Error']['Code'] == 'NoSuchBucket':
            print(f"\nThe bucket named {args.bucket} does not exist on the {args.aws_region} region\n")
            print('Request ID: {}'.format(err.response['ResponseMetadata']['RequestId']))
            print('Http code: {}'.format(err.response['ResponseMetadata']['HTTPStatusCode']))
        else:
            print("Error occured : ", err)

if __name__ == "__main__":
    list_bucket_objects(bucket_args())
